package Bundle::Locale::CLDR::Centralasia;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Centralasia

=head1 CONTENTS

Locale::CLDR::Locales::Kk 0.34.1
Locale::CLDR::Locales::Ky 0.34.1
Locale::CLDR::Locales::Ru 0.34.1
Locale::CLDR::Locales::Tg 0.34.1
Locale::CLDR::Locales::Tk 0.34.1
Locale::CLDR::Locales::Uz 0.34.1
Locale::CLDR::Locales::Kk::Any 0.34.1
Locale::CLDR::Locales::Ky::Any 0.34.1
Locale::CLDR::Locales::Ru::Any 0.34.1
Locale::CLDR::Locales::Tg::Any 0.34.1
Locale::CLDR::Locales::Tk::Any 0.34.1
Locale::CLDR::Locales::Uz::Cyrl 0.34.1
Locale::CLDR::Locales::Uz::Latn 0.34.1
Locale::CLDR::Locales::Kk::Any::Kz 0.34.1
Locale::CLDR::Locales::Ky::Any::Kg 0.34.1
Locale::CLDR::Locales::Ru::Any::Kg 0.34.1
Locale::CLDR::Locales::Ru::Any::Kz 0.34.1
Locale::CLDR::Locales::Tg::Any::Tj 0.34.1
Locale::CLDR::Locales::Tk::Any::Tm 0.34.1
Locale::CLDR::Locales::Uz::Cyrl::Uz 0.34.1
Locale::CLDR::Locales::Uz::Latn::Uz 0.34.1

=cut

1;

